summaryrefslogtreecommitdiff
path: root/src/or/hs_service.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/or/hs_service.c')
-rw-r--r--src/or/hs_service.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/or/hs_service.c b/src/or/hs_service.c
index d6416ebcd6..3500e497bd 100644
--- a/src/or/hs_service.c
+++ b/src/or/hs_service.c
@@ -2428,8 +2428,8 @@ set_descriptor_revision_counter(hs_service_descriptor_t *hs_desc, time_t now,
rev_counter = crypto_ope_encrypt(hs_desc->ope_cipher,
(int) seconds_since_start_of_srv);
- /* The OPE module returns UINT64_MAX in case of errors. */
- tor_assert_nonfatal(rev_counter < UINT64_MAX);
+ /* The OPE module returns CRYPTO_OPE_ERROR in case of errors. */
+ tor_assert_nonfatal(rev_counter < CRYPTO_OPE_ERROR);
log_info(LD_REND, "Encrypted revision counter %d to %ld",
(int) seconds_since_start_of_srv, (long int) rev_counter);